<?php

declare(strict_types=1);

namespace Drupal\flysystem;

use Drupal\Core\Config\Entity\ConfigEntityInterface;

/**
 * Provides an interface defining a flysystem_adapter_config entity type.
 */
interface FlysystemAdapterConfigInterface extends ConfigEntityInterface {

  /**
   * Determines whether Flysystem adapter is valid.
   *
   * @return bool
   *   TRUE if valid, FALSE otherwise.
   */
  public function hasValidSubAdapter();

  /**
   * Retrieves the Flysystem adapter.
   *
   * @return \Drupal\flysystem\FlysystemAdapterInterface
   *   This adapter config entity's Flysystem adapter.
   *
   * @throws \Drupal\flysystem\FlysystemException
   *   Thrown if the adapter plugin could not be retrieved.
   */
  public function getSubAdapter();

  /**
   * Retrieves plugin ID of the Flysystem (sub)adapter of this config entity.
   *
   * @return string
   *   The plugin ID of the subadapter.
   */
  public function getSubAdapterId();

  /**
   * Return the configuration of this config entity's Flysystem (sub)adapter.
   *
   * @return array
   *   An associative array with the subadapter configuration.
   */
  public function getSubAdapterConfig();

  /**
   * Get adapter config description.
   *
   * @return string
   *   Adapter config description.
   */
  public function getDescription();

  /**
   * Returns the value of a configuration item from the key.
   *
   * @param string|array $key
   *   Key or array of keys of item in the configuration array.
   *
   * @return mixed
   *   Value to return from array key.
   */
  public function getSubAdapterConfigItem($key);

}
