<?php

namespace Drupal\flysystem;

use Drupal\Core\DependencyInjection\ContainerBuilder;
use Drupal\Core\DependencyInjection\ServiceProviderBase;
use Symfony\Component\DependencyInjection\Reference;

/**
 * Registers Flysystem Stream Wrappers.
 *
 * Registers stream wrappers using the configured Flysystem adapters.
 */
class FlysystemServiceProvider extends ServiceProviderBase {

  /**
   * {@inheritdoc}
   */
  public function register(ContainerBuilder $container): void {
    /** @var \Drupal\Core\Config\CachedStorage $config_storage */
    $config_storage = $container->get('config.storage');
    $entity_config_names = $config_storage->listAll('flysystem.flysystem_adapter_config');
    $configured_entities = $config_storage->readMultiple($entity_config_names);

    foreach ($configured_entities as $key => $value) {
      if (empty($value)) {
        // This should never happen, however if it does skip this entry.
        continue;
      }

      if ($value['status'] !== TRUE) {
        // Scheme is not enabled.
        continue;
      }
      $container
        ->register('stream_wrapper.' . $value['id'], 'Drupal\flysystem\FlyStream\FlyStreamWrapper')
        ->addTag('stream_wrapper', ['scheme' => $value['id']])
        ->setArguments([$key, new Reference('config.storage')]);
    }
  }

}
